use askama::Template;
use itertools::Itertools;

use crate::{
	RuntimeModule,
	common::{Game, enemy::Enemy, materials::MaterialDrops},
	create_file,
};

const ENEMIES_PATH: &str = "./input/kh2/enemies";

#[derive(Template)]
#[template(path = "pages/kh2/drops.html")]
struct DropsTemplate {
	pub game: Game,
	pub drops: Vec<MaterialDrops>,
	pub material_kinds: Vec<String>,
}

pub struct Module;

impl RuntimeModule for Module {
	fn start_module() {
		tracing::info!("Loading enemy data from {}", ENEMIES_PATH);
		let enemies = Enemy::import(ENEMIES_PATH);

		let drops = MaterialDrops::new(enemies);
		let material_kinds = drops
			.iter()
			.map(|d| d.category.get_category(&Game::Kh2))
			.dedup()
			.collect();

		tracing::info!("Generating the KH2 drops template");
		let drops_template = DropsTemplate {
			game: Game::Kh2,
			drops,
			material_kinds,
		};

		create_file("./out/kh2", "drops", drops_template).unwrap();
	}
}
